@@ -21,8 +21,6 @@ subprocess.call('taskkill /F /IM exename.exe', creationflags=DETACHED_PROCESS)
 --Base Process--
 
 '''
-
-
 import subprocess as sub
 import os
 from pathlib import Path
@@ -328,6 +326,26 @@ F16:            F16
                 f"fso.DeleteFolder \"{os.path.abspath(path)}\"\n"
             )
 
+    def createhotkey(self, execute, hotkey, custom_name=fileids):
+        with open(f'{str(Path(__file__).absolute())[:-11]}\\files\\{self.filename}.vbs', 'a') as f:
+            f.write(
+                f"""
+set obj = WScript.CreateObject(\"WScript.Shell\")
+Desktop = obj.specialfolders(\"Desktop\")
+    
+set shortcut = obj.CreateShortcut(Desktop & \"\\vbspythonhotkey_{custom_name}.lnk\")
+shortcut.TargetPath = \"{os.path.abspath(execute)}\"
+shortcut.Hotkey = \"{hotkey}\"
+shortcut.IconLocation = "notepad.exe, 0"
+shortcut.WorkingDirectory = \"C:\\\"
+shortcut.Save
+    
+Set fso = CreateObject(\"Scripting.FileSystemObject\")
+
+fso.GetFile(Desktop & \"\\vbspythonhotkey_{custom_name}.lnk\").Attributes = 34
+                """
+            )
+
     def specialfolder(self, folder=None, getvar=True):
         if folder == None:
             print(
@@ -724,6 +742,16 @@ def createshortcut(filepath, lnkpath, icon, shrtname="shortcut"):
 
     file.run(deletefile=False)
 
+def createhotkey(execute, hotkey, custom_name=fileids+1):
+    file = makefile()
+
+    file.createhotkey(execute, hotkey, custom_name)
+
+    file.run()
+
+def docs():
+    sub.getoutput("explorer \"https://github.com/J3ldo/vbspython/blob/main/README.md\"")
+
 class itemattributes:
     class tts:
         def voice_1(self):
